AxisParameters

Struct AxisParameters 

pub struct AxisParameters {
    pub name: Option<String>,
    pub default_dimension: Option<f32>,
    pub dimension_range: Rangef,
    pub resizable: bool,
    pub monospace: bool,
    pub expandable: bool,
}
Specifies the axis (row/column) parameters.

Since min/max/default dimension can all conflict or be specified in a different order they must be sanitized before use in the following order: default -> clamp(min, max)

debug_asserts are raised if any values are < 0 in release builds default/min/max have a minimum of 0 at runtime.

Fields

name: Option<String>default_dimension: Option<f32>

The row/column height/width, respectively

dimension_range: Rangef

The row/column height/width range, respectively

resizable: boolmonospace: boolexpandable: bool

Implementations

Source

impl AxisParameters

pub fn name(self, s: impl Into<String>) -> Self

pub fn default_dimension(self, value: f32) -> Self

The row/column height/width, respectively

pub fn minimum_dimension(self, value: f32) -> Self

default: 10.0

if the row/column is resizable, then the minimum dimension might be larger the value specified here, or the default, due to the space required for resize handles and resize handle interaction constraints

pub fn maximum_dimension(self, value: f32) -> Self

a value f32::INFINITY allows the row/column to be resized to be as large as possible

default: f32::INFINITY

pub fn resizable(self, value: bool) -> Self

pub fn monospace(self, value: bool) -> Self

pub fn expandable(self, value: bool) -> Self

indicates if this column can be expanded to fill the available space does NOT imply the USER can resize it

If there are multiple expandable columns then only the first one encountered will be expanded. Thus, it’s not advisable to set it on more than one column, especially if you are using column reordering.

Currently not applicable to rows.